Activate extension command

### Navigation

- index
- next |
- previous |
- fantastico 0.4.0-b114 documentation »
- Fantastico features »
- SDK »

# Activate extension command

This Fantastico command helps developers integrate existing components into their project very easy. One use case is to activate in your projects contrib components (e.g: Dynamic menu). It is strongly recommended to use this sdk command because it works on every supported operating system.

class `fantastico.sdk.commands.command_activate_extension.` `SdkCommandActivateExtension`(argv, cmd_factory)

  This class provides the functionality for activating off the shelf fantastico extensions. As developer, it is extremely easy to integrate provided functionality into fantastico. For now, it supports only local extensions provided into fantastico.contrib package. In the future, we plan to support activation of remote components into projects.

      # replace <project_root_path> with your fantastico project location.
      cd <project_root_path>

      # replace <component_root_path> with your actual folder.
      fsdk activate-extension --name dynamic_menu --comp-root <component_root_path>

  `exec`(os_lib=<module 'os' from '/mnt/jenkins_ebs/continous_integration/fantastico_doc_workspace/pip-deps/lib/python3.2/os.py'>)

    This method is executed to activate the given extension name.

  `get_arguments`()

    This method returns support arguments of activate-extension command.

  `get_help`()

    This method returns the friendly help message describing the method.